==> openjdk-12_12.0.2+9.orig.tar.xz: openjdk-12-12.0.2+9/src/hotspot/share/gc/parallel/heterogeneousGenerationSizer.hpp <==
/*
 * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_VM_GC_PARALLEL_HETEROGENEOUSGENERATIONSIZER_HPP
#define SHARE_VM_GC_PARALLEL_HETEROGENEOUSGENERATIONSIZER_HPP

#include "gc/parallel/generationSizer.hpp"

// There is a nice batch of tested generation sizing code in
// GenCollectorPolicy. Lets reuse it!

class HeterogeneousGenerationSizer : public GenerationSizer {
private:
  // Max fraction of dram to use for young generation when MaxRAMFraction and
  // MaxRAMPercentage are not specified on commandline.
  static const double MaxRamFractionForYoung;

protected:
  virtual void initialize_flags();

public:
  virtual size_t heap_reserved_size_bytes() const;
  virtual bool is_hetero_heap() const;
};
#endif // SHARE_VM_GC_PARALLEL_HETEROGENEOUSGENERATIONSIZER_HPP

==> openjdk-13_13~17.orig.tar.xz: openjdk-13-13~17/src/hotspot/share/gc/parallel/heterogeneousGenerationSizer.hpp <==
/*
 * Copyright (c) 2018, 2019, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 *
 */

#ifndef SHARE_GC_PARALLEL_HETEROGENEOUSGENERATIONSIZER_HPP
#define SHARE_GC_PARALLEL_HETEROGENEOUSGENERATIONSIZER_HPP

#include "gc/parallel/generationSizer.hpp"

// There is a nice batch of tested generation sizing code in
// GenCollectorPolicy. Lets reuse it!

class HeterogeneousGenerationSizer : public GenerationSizer {
private:
  // Max fraction of dram to use for young generation when MaxRAMFraction and
  // MaxRAMPercentage are not specified on commandline.
  static const double MaxRamFractionForYoung;

protected:
  virtual void initialize_flags();

public:
  virtual size_t heap_reserved_size_bytes() const;
  virtual bool is_hetero_heap() const;
};
#endif // SHARE_GC_PARALLEL_HETEROGENEOUSGENERATIONSIZER_HPP
